View source: R/remove_tex_value.R
| remove_tex_value | R Documentation |
Remove certain values from a values-tex file
remove_tex_value(names, file_name, path = NULL)
names |
Character vector of names specifying which values are to be removed. |
file_name |
File name containing values to be removed. file_name should have either a .tex extension or no extension at all. |
path |
Path to the directory to save the file to. |
## Not run:
file <- tempfile()
save_tex_value(values = 1:3, names = c("a","b","c"), file_name = file)
# remove "a" and "b" from file
remove_tex_value(file_name = paste0(file, ".tex"), names = c("a", "b"))
# delete file with base::unlink()
unlink(paste0(file,".tex"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.